2003-10-10 Kei Sakamoto <sakamoto.kei@renesas.com>
authorKazuhiro Inaoka <inaoka.kazuhiro@renesas.com>
Fri, 10 Oct 2003 07:13:11 +0000 (07:13 +0000)
committerKazuhiro Inaoka <inaoka.kazuhiro@renesas.com>
Fri, 10 Oct 2003 07:13:11 +0000 (07:13 +0000)
* NEWS: Replace "Hitachi" and "Mitsubishi" with "Renesas".
* README: Ditto.
* d10v-tdep.c: Ditto.
* h8300-tdep.c: Ditto.
* remote-e7000.c: Ditto.
* remote-hms.c: Ditto.
* ser-e7kpc.c: Ditto.
* sh-stub.c: Ditto.
* sh-tdep.c: Ditto.
* sh-tdep.h: Ditto.
* sh3-rom.c: Ditto.
* sh64-tdep.c: Ditto.
* top.c: Ditto.
* wince.c: Ditto.
* config/d10v/d10v.mt: Ditto.
* config/sh/embed.mt: Ditto.
* config/sh/linux.mt: Ditto.
* config/sh/tm-linux.h: Ditto.
* config/sh/tm-sh.h: Ditto.
* config/sh/wince.mt: Ditto.

21 files changed:
gdb/ChangeLog
gdb/NEWS
gdb/README
gdb/config/d10v/d10v.mt
gdb/config/sh/embed.mt
gdb/config/sh/linux.mt
gdb/config/sh/tm-linux.h
gdb/config/sh/tm-sh.h
gdb/config/sh/wince.mt
gdb/d10v-tdep.c
gdb/h8300-tdep.c
gdb/remote-e7000.c
gdb/remote-hms.c
gdb/ser-e7kpc.c
gdb/sh-stub.c
gdb/sh-tdep.c
gdb/sh-tdep.h
gdb/sh3-rom.c
gdb/sh64-tdep.c
gdb/top.c
gdb/wince.c

index 912545d3dbf22c1ebc0b25b66edd4257b26bcf89..0d7dbfe7f28fa9df9f94a913f0179b3e46a1d945 100644 (file)
@@ -1,3 +1,26 @@
+2003-10-10  Kei Sakamoto  <sakamoto.kei@renesas.com>
+
+       * NEWS: Replace "Hitachi" and "Mitsubishi" with "Renesas".
+       * README: Ditto.
+       * d10v-tdep.c: Ditto.
+       * h8300-tdep.c: Ditto.
+       * remote-e7000.c: Ditto.
+       * remote-hms.c: Ditto.
+       * ser-e7kpc.c: Ditto.
+       * sh-stub.c: Ditto.
+       * sh-tdep.c: Ditto.
+       * sh-tdep.h: Ditto.
+       * sh3-rom.c: Ditto.
+       * sh64-tdep.c: Ditto.
+       * top.c: Ditto.
+       * wince.c: Ditto.
+       * config/d10v/d10v.mt: Ditto.
+       * config/sh/embed.mt: Ditto.
+       * config/sh/linux.mt: Ditto.
+       * config/sh/tm-linux.h: Ditto.
+       * config/sh/tm-sh.h: Ditto.
+       * config/sh/wince.mt: Ditto.
+
 2003-10-09  Andrew Cagney  <cagney@redhat.com>
 
        * ppc-tdep.h (struct type): Declare opaque.
index 83d6dfd7676b7a8da953eac438d533c494a3a8d5..d47863baf75e379a1245a814d9193b8df52a9ff8 100644 (file)
--- a/gdb/NEWS
+++ b/gdb/NEWS
@@ -141,7 +141,7 @@ FreeBSD/amd64                                       x86_64-*-freebsd*
 * Multi-arched targets.
 
 HP/PA HPUX11                                    hppa*-*-hpux*
-Mitsubishi M32R/D w/simulator                  m32r-*-elf*
+Renesas M32R/D w/simulator                     m32r-*-elf*
 
 * OBSOLETE configurations and files
 
index bae1a2e37b94fdbdbbbd133f44879aa2e5360e50..d2fb8ab52baff801ec893a3720d845722fa40722 100644 (file)
@@ -462,9 +462,9 @@ Linux.
    There are a number of remote interfaces for talking to existing ROM
 monitors and other hardware:
 
-       remote-e7000.c   Hitachi E7000 ICE
+       remote-e7000.c   Renesas E7000 ICE
        remote-est.c     EST emulator
-       remote-hms.c     Hitachi Micro Systems H8/300 monitor
+       remote-hms.c     Renesas Micro Systems H8/300 monitor
        remote-mips.c    MIPS remote debugging protocol
        remote-rdi.c     ARM with Angel monitor
        remote-rdp.c     ARM with Demon monitor
index 72680e22dfb46a3bace1a13dc507e6ef1c7f190c..805ce7658a6ae526dd02459b5a2da630e164de86 100644 (file)
@@ -1,4 +1,4 @@
-# Target: Mitsubishi D10V processor
+# Target: Renesas D10V processor
 TDEPFILES= d10v-tdep.o
 SIM_OBS= remote-sim.o
 SIM= ../sim/d10v/libsim.a
index 4c82134718826e04688c8e31ec1f36e63ccf1393..807aa110e9920006dab1139cd1deaf83ec5bc94e 100644 (file)
@@ -1,4 +1,4 @@
-# Target: Embedded Hitachi Super-H with ICE and simulator
+# Target: Embedded Renesas Super-H with ICE and simulator
 TDEPFILES= sh-tdep.o sh64-tdep.o monitor.o sh3-rom.o remote-e7000.o ser-e7kpc.o dsrec.o 
 TM_FILE= tm-sh.h
 
index 92ab4c4daf1b0d2a9ee8d5cade18bf13f3e9d120..83ada467161a990d2204684188e7011a61ad699f 100644 (file)
@@ -1,4 +1,4 @@
-# Target: Hitachi Super-H running GNU/Linux
+# Target: Renesas Super-H running GNU/Linux
 TDEPFILES= sh-tdep.o sh64-tdep.o monitor.o sh3-rom.o remote-e7000.o ser-e7kpc.o dsrec.o solib.o solib-svr4.o solib-legacy.o
 TM_FILE= tm-linux.h
 
index e8272d02e372b8eecdfd67fc1f01b49d0db4194e..0117d813da88a911a5bf9a96bc8301bb8ade0ffd 100644 (file)
@@ -1,4 +1,4 @@
-/* Target-specific definitions for GNU/Linux running on a Hitachi
+/* Target-specific definitions for GNU/Linux running on a Renesas
    Super-H.
 
    Copyright 2000, 2002 Free Software Foundation, Inc.
index 966c8cd95c63364427c406b1aeb601050a0693ea..228e0bcc5f36a96c1750d9ea5289fe80d8d336a0 100644 (file)
@@ -1,4 +1,4 @@
-/* Target-specific definition for a Hitachi Super-H.
+/* Target-specific definition for a Renesas Super-H.
    Copyright 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002
    Free Software Foundation, Inc.
 
index 342c2d6b4d2823b5bc156ec96218212218bf25bc..89a5a89ce69942777866cf5b31590dab946f6220 100644 (file)
@@ -1,4 +1,4 @@
-# Target: Hitachi Super-H running on Windows CE
+# Target: Renesas Super-H running on Windows CE
 TDEPFILES= sh-tdep.o sh64-tdep.o wince.o
 TM_FILE= tm-wince.h
 MT_CFLAGS=-DSHx -U_X86_ -U_M_IX86 -U__i386__ -U__i486__ -U__i586__ -U__i686__ -DUNICODE -D_WIN32_WCE -DWINCE_STUB='"${target_alias}-stub.exe"'
index 4dbb1f1fbd1c6ab0010150bbb9cf4f8014210dd9..3090cc8bca4ec438c60e0fb334da58ac37779f36 100644 (file)
@@ -1,4 +1,4 @@
-/* Target-dependent code for Mitsubishi D10V, for GDB.
+/* Target-dependent code for Renesas D10V, for GDB.
 
    Copyright 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003 Free Software
    Foundation, Inc.
index 69155cefdf0daa141874e526b528e0226467f28a..4e22b831ee7fa7f7655aa40f9d003e3b5575468d 100644 (file)
@@ -1,4 +1,4 @@
-/* Target-machine dependent code for Hitachi H8/300, for GDB.
+/* Target-machine dependent code for Renesas H8/300, for GDB.
 
    Copyright 1988, 1990, 1991, 1992, 1993, 1994, 1995, 1996, 1998,
    1999, 2000, 2001, 2002, 2003 Free Software Foundation, Inc.
index d95590d0f7444bbb31622d3411224fb2493c333b..10d7362ee9a9354e7f794e55ca557868cee6e996 100644 (file)
@@ -1,4 +1,4 @@
-/* Remote debugging interface for Hitachi E7000 ICE, for GDB
+/* Remote debugging interface for Renesas E7000 ICE, for GDB
 
    Copyright 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001,
    2002, 2003 Free Software Foundation, Inc.
@@ -24,8 +24,8 @@
    Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.  */
 
-/* The E7000 is an in-circuit emulator for the Hitachi H8/300-H and
-   Hitachi-SH processor.  It has serial port and a lan port.  
+/* The E7000 is an in-circuit emulator for the Renesas H8/300-H and
+   Renesas-SH processor.  It has serial port and a lan port.  
 
    The monitor command set makes it difficult to load large ammounts of
    data over the lan without using ftp - so try not to issue load
@@ -2131,8 +2131,8 @@ static void
 init_e7000_ops (void)
 {
   e7000_ops.to_shortname = "e7000";
-  e7000_ops.to_longname = "Remote Hitachi e7000 target";
-  e7000_ops.to_doc = "Use a remote Hitachi e7000 ICE connected by a serial line;\n\
+  e7000_ops.to_longname = "Remote Renesas e7000 target";
+  e7000_ops.to_doc = "Use a remote Renesas e7000 ICE connected by a serial line;\n\
 or a network connection.\n\
 Arguments are the name of the device for the serial line,\n\
 the speed to connect at in bits per second.\n\
index cd7f4d39c4960e58c238de5d1cf00b99d43197b5..ee40051fb3c1a794076e939d3b27fab0744c8a28 100644 (file)
@@ -1,4 +1,4 @@
-/* Remote debugging interface for Hitachi HMS Monitor Version 1.0
+/* Remote debugging interface for Renesas HMS Monitor Version 1.0
    Copyright 1995, 1996, 1998, 1999, 2000, 2001
    Free Software Foundation, Inc.
    Contributed by Cygnus Support.  Written by Steve Chamberlain
@@ -149,7 +149,7 @@ _initialize_remote_hms (void)
   init_monitor_ops (&hms_ops);
 
   hms_ops.to_shortname = "hms";
-  hms_ops.to_longname = "Hitachi Microsystems H8/300 debug monitor";
+  hms_ops.to_longname = "Renesas Microsystems H8/300 debug monitor";
   hms_ops.to_doc = "Debug via the HMS monitor.\n\
 Specify the serial device it is connected to (e.g. /dev/ttya).";
   hms_ops.to_open = hms_open;
index 8496ae411a25ce9ec7dbd5b679299603848cfc8a..1efe1420575924f1ce99478c293ab2f363b4d1aa 100644 (file)
@@ -1,4 +1,4 @@
-/* Remote serial interface using Hitachi E7000 PC ISA card in a PC
+/* Remote serial interface using Renesas E7000 PC ISA card in a PC
    Copyright 1994, 1996, 1997, 1998, 1999, 2000
    Free Software Foundation, Inc.
 
index 73357b4a94ed3a6da4121a7ab16baef0a4d9e7e2..bdd9e501b861b4ffc2c2dbe7176bf8ced4e614c9 100644 (file)
@@ -1,4 +1,4 @@
-/* sh-stub.c -- debugging stub for the Hitachi-SH.
+/* sh-stub.c -- debugging stub for the Renesas-SH.
 
  NOTE!! This code has to be compiled with optimization, otherwise the 
  function inlining which generates the exception handlers won't work.
 #include <string.h>
 #include <setjmp.h>
 
-/* Hitachi SH architecture instruction encoding masks */
+/* Renesas SH architecture instruction encoding masks */
 
 #define COND_BR_MASK   0xff00
 #define UCOND_DBR_MASK 0xe000
 #define UCOND_DISP     0x0fff
 #define UCOND_REG      0x0f00
 
-/* Hitachi SH instruction opcodes */
+/* Renesas SH instruction opcodes */
 
 #define BF_INSTR       0x8b00
 #define BT_INSTR       0x8900
 #define TRAPA_INSTR    0xc300
 #define SSTEP_INSTR    0xc3ff
 
-/* Hitachi SH processor register masks */
+/* Renesas SH processor register masks */
 
 #define T_BIT_MASK     0x0001
 
@@ -824,7 +824,7 @@ breakpoint (void)
 
 /* Note:
 
-   The Hitachi SH family uses two exception architectures:
+   The Renesas SH family uses two exception architectures:
 
    SH1 & SH2:
 
index c42e4113b4272644b5afc31a011f45943c74d03e..a220493f38f0313adea0680826065d9591bc1e88 100644 (file)
@@ -1,4 +1,4 @@
-/* Target-dependent code for Hitachi Super-H, for GDB.
+/* Target-dependent code for Renesas Super-H, for GDB.
    Copyright 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003
    Free Software Foundation, Inc.
 
@@ -614,7 +614,7 @@ sh_frame_align (struct gdbarch *ignore, CORE_ADDR sp)
 /* Function: push_dummy_call (formerly push_arguments)
    Setup the function arguments for calling a function in the inferior.
 
-   On the Hitachi SH architecture, there are four registers (R4 to R7)
+   On the Renesas SH architecture, there are four registers (R4 to R7)
    which are dedicated for passing function arguments.  Up to the first
    four arguments (depending on size) may go into these registers.
    The rest go on the stack.
index e609b52848a6cdc5bd39de873387a06597368f8d..9c84c67db7d307a479aa621fd8240e84919947b8 100644 (file)
@@ -1,4 +1,4 @@
-/* Target-specific definition for a Hitachi Super-H.
+/* Target-specific definition for a Renesas Super-H.
    Copyright 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003
    Free Software Foundation, Inc.
 
index a2e21c198c8381603a208bdd8d92627817158fce..cec9fbae85bf0d797bb328cb33b16026567f8eb5 100644 (file)
@@ -1,4 +1,4 @@
-/* Remote target glue for the Hitachi SH-3 ROM monitor.
+/* Remote target glue for the Renesas SH-3 ROM monitor.
    Copyright 1995, 1996, 1997, 1998, 1999, 2000, 2001
    Free Software Foundation, Inc.
 
@@ -365,11 +365,11 @@ _initialize_sh3_rom (void)
   init_monitor_ops (&sh3_ops);
 
   sh3_ops.to_shortname = "sh3";
-  sh3_ops.to_longname = "Hitachi SH-3 rom monitor";
+  sh3_ops.to_longname = "Renesas SH-3 rom monitor";
 
   sh3_ops.to_doc =
   /* We can download through the parallel port too. */
-    "Debug on a Hitachi eval board running the SH-3E rom monitor.\n"
+    "Debug on a Renesas eval board running the SH-3E rom monitor.\n"
     "Specify the serial device it is connected to.\n"
     "If you want to use the parallel port to download to it, specify that\n"
     "as an additional second argument.";
@@ -384,11 +384,11 @@ _initialize_sh3_rom (void)
   init_monitor_ops (&sh3e_ops);
 
   sh3e_ops.to_shortname = "sh3e";
-  sh3e_ops.to_longname = "Hitachi SH-3E rom monitor";
+  sh3e_ops.to_longname = "Renesas SH-3E rom monitor";
 
   sh3e_ops.to_doc =
   /* We can download through the parallel port too. */
-    "Debug on a Hitachi eval board running the SH-3E rom monitor.\n"
+    "Debug on a Renesas eval board running the SH-3E rom monitor.\n"
     "Specify the serial device it is connected to.\n"
     "If you want to use the parallel port to download to it, specify that\n"
     "as an additional second argument.";
index 5188cfd8e1d8f3036d6048efae600a3cceb3c178..ca87b8e86f1f839e7571cafb5d1bf9f7f9e977de 100644 (file)
@@ -1,4 +1,4 @@
-/* Target-dependent code for Hitachi Super-H, for GDB.
+/* Target-dependent code for Renesas Super-H, for GDB.
    Copyright 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003
    Free Software Foundation, Inc.
 
@@ -1414,7 +1414,7 @@ sh_frame_align (struct gdbarch *ignore, CORE_ADDR sp)
 /* Function: push_arguments
    Setup the function arguments for calling a function in the inferior.
 
-   On the Hitachi SH architecture, there are four registers (R4 to R7)
+   On the Renesas SH architecture, there are four registers (R4 to R7)
    which are dedicated for passing function arguments.  Up to the first
    four arguments (depending on size) may go into these registers.
    The rest go on the stack.
index 0e22c1fa3e8fa6fe502d0299319cdbdb9613a3e3..1e3399d18102d17609ff06f78ac074984837b6e7 100644 (file)
--- a/gdb/top.c
+++ b/gdb/top.c
@@ -147,7 +147,7 @@ int baud_rate = -1;
    In mid-1996, remote_timeout was moved from remote.c to top.c and 
    it began being used in other remote-* targets.  It appears that the
    default was changed to 20 seconds at that time, perhaps because the
-   Hitachi E7000 ICE didn't always respond in a timely manner.
+   Renesas E7000 ICE didn't always respond in a timely manner.
 
    But if 5 seconds is a long time to sit and wait for retransmissions,
    20 seconds is far worse.  This demonstrates the difficulty of using 
index fc07e4fa93b0b53a4dd5ccf3a6275c713be0589b..0e1746dc89d7c26913e06619f1f3af54315c7676 100644 (file)
@@ -833,7 +833,7 @@ wince_software_single_step (enum target_signal ignore,
   return;
 }
 #elif SHx
/* Hitachi SH architecture instruction encoding masks */
 
 #define COND_BR_MASK   0xff00
 #define UCOND_DBR_MASK 0xe000
@@ -844,7 +844,7 @@ wince_software_single_step (enum target_signal ignore,
 #define UCOND_DISP     0x0fff
 #define UCOND_REG      0x0f00
 
/* Hitachi SH instruction opcodes */
 
 #define BF_INSTR       0x8b00
 #define BT_INSTR       0x8900
@@ -833,7 +833,7 @@ wince_software_single_step (enum target_signal ignore,
 }
 #elif SHx
-/* Hitachi SH architecture instruction encoding masks */
+/* Renesas SH architecture instruction encoding masks */
 
 #define COND_BR_MASK   0xff00
@@ -844,7 +844,7 @@ wince_software_single_step (enum target_signal ignore,
 #define UCOND_REG      0x0f00
 
-/* Hitachi SH instruction opcodes */
+/* Renesas SH instruction opcodes */
 
 #define BF_INSTR       0x8b00
This page took 0.043389 seconds and 4 git commands to generate.